==> nextcloud-19.0.3.tgz: nextcloud/apps/accessibility/l10n/ro.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Temă întunecată",
    "Enable dark theme" : "Activați tema întunecată",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temă întunecată pentru ușurarea ochilor prin reducerea generală a luminozității. Temă în curs de dezvoltare deci vă rugăm să raportați orice problemă găsită.",
    "High contrast mode" : "Modul contrast puternic.",
    "Enable high contrast mode" : "Activați tema cu contrast înalt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un contrast puternic poate ușura utilizarea. Calitatea vizuală va fi redusă, dar claritatea va fi ridicată.",
    "Dyslexia font" : "Font dislexic",
    "Enable dyslexia font" : "Activați fontul pentru dislexie",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic este un tip de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie.",
    "Accessibility" : "Accesibilitate",
    "Accessibility options for nextcloud" : "Opțiuni de accesibilitate pentru nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Vă oferă opțiuni multiple de accesibilitate pentru a simplifica utilizarea Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Accesul universal este foarte important pentru noi. Urmărim standardele web și verificăm să facem ca toate funcțiile să poată fii utilizate și fără mouse și software de asistență, cum ar fi sofware de citit ecranul. Ne propunem să fim conformi cu {guidelines} Accesibilitatea conținutului web {linkend} 2.1 la nivel AA, cu tema de contrast ridicat chiar și la nivel AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Dacă găsiți probleme, nu ezitați să le raportați la {issuetracker} următorul nostru de probleme {linkend}. Și dacă doriți să vă implicați, participați la {designteam} echipa noastră de design {linkend}!",
    "High contrast theme" : "Temă cu contrast înalt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Temă cu contrast înalt pentru ușurarea navigării. Calitatea visuală va fi redusă dar claritatea va fi mărită.",
    "Web Content Accessibility Guidelines" : "Instrucțiuni privind accesibilitatea conținutului web",
    "our issue tracker" : "instrumentul nostru de urmărire a problemelor",
    "our design team" : "echipa noastră de design",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Accesul universal este foarte important pentru noi. Urmărim standardele web și verificăm să facem ca toate funcțiile să poată fii utilizate și fără mouse și software de asistență, cum ar fi sofware de citit ecranul. Ne propunem să fim conformi cu {guidelines} 2.1 la nivel AA, cu tema de contrast ridicat chiar și la nivel AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Dacă găsiți probleme, nu ezitați să le raportați la {issuetracker}. Și dacă doriți să vă implicați, unițivă la {designteam}!",
    "Enable" : "Activează"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-22.2.10.tgz: nextcloud/apps/accessibility/l10n/ro.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Temă întunecată",
    "Enable dark theme" : "Activați tema întunecată",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "O temă întunecată pentru ușurarea ochilor prin reducerea generală a luminozității. Temă în curs de dezvoltare deci vă rugăm să raportați orice problemă găsită.",
    "High contrast mode" : "Modul contrast puternic.",
    "Enable high contrast mode" : "Activați tema cu contrast înalt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un contrast puternic poate ușura utilizarea. Calitatea vizuală va fi redusă, dar claritatea va fi ridicată.",
    "Dyslexia font" : "Font dislexic",
    "Enable dyslexia font" : "Activați fontul pentru dislexie",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic este un tip de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie.",
    "Accessibility" : "Accesibilitate",
    "Accessibility options for nextcloud" : "Opțiuni de accesibilitate pentru nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Vă oferă opțiuni multiple de accesibilitate pentru a simplifica utilizarea Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Accesul universal este foarte important pentru noi. Urmărim standardele web și verificăm să facem ca toate funcțiile să poată fii utilizate și fără mouse și software de asistență, cum ar fi sofware de citit ecranul. Ne propunem să fim conformi cu {guidelines} Accesibilitatea conținutului web {linkend} 2.1 la nivel AA, cu tema de contrast ridicat chiar și la nivel AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Dacă găsiți probleme, nu ezitați să le raportați la {issuetracker} tracker-ul nostru de probleme {linkend}. Și dacă doriți să vă implicați, participați în {designteam} echipa noastră de design {linkend}!"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
